@@ -16,16 +16,18 @@ import h5py
 import pandas as pd
 import numpy as np
 from pandas import DataFrame, Series
-from .config import data_path, cal_config
+from .config import data_path
 from .reader_utils import Cal, Inst
+from .tools import read_version_config
 import os
 
 
 class FeatureUpdater:
 
     def __init__(self, stk_univ="all", start_time=None, end_time=None, freq="Tday", is_alpha=False):
-        start_time = cal_config[freq]["si"] if start_time is None else start_time
-        end_time = cal_config[freq]["ei"] if end_time is None else end_time
+        self.cal_config = read_version_config()["cal_config"]
+        start_time = self.cal_config[freq]["si"] if start_time is None else start_time
+        end_time = self.cal_config[freq]["ei"] if end_time is None else end_time
         _, calendar_index = Cal._get_calendar(freq=freq)
         self.stk_univ = sorted(list(Inst.list_instruments(stk_univ, start_time, end_time).keys()))
         self.time_idx = Cal.calendar(start_time, end_time, freq=freq)
@@ -69,7 +71,7 @@ class FeatureUpdater:
             config = {}
         value_dict = Mdf.to_dict("series")
         if self.is_alpha:
-            value_dict.pop(cal_config[self.freq]["col_name"])
+            value_dict.pop(self.cal_config[self.freq]["col_name"])
         for field, values in value_dict.items():
             config_i = config.get(field, None)
             self.save_series(field, values, config_i)
@@ -95,6 +97,7 @@ class FeatureSaver(FeatureUpdater):
 
     def save_alpha(self, alpha, alpha_name):
         alpha = alpha.rename(columns={"value": alpha_name})
-        self.save_values(alpha, cal_config[self.freq]["col_name"], "stockcode")
+        self.save_values(alpha, self.cal_config[self.freq]["col_name"], "stockcode")
+
 
 print("res")
\ No newline at end of file
